@@ -6,10 +6,11 @@ from typing import Any, Callable, Dict, List, Optional
 from justpy import WebPage
 
 from ..events import MouseEventArguments, handle_event
+from ..routes import add_dependencies
 from .custom_view import CustomView
 from .element import Element
 
-CustomView.use(__file__)
+add_dependencies(__file__)
 
 
 class InteractiveImageView(CustomView):
