@@ -1,9 +1,10 @@
 from typing import Any, Callable, Optional
 
+from ..routes import add_dependencies
 from .custom_view import CustomView
 from .element import Element
 
-CustomView.use(__file__, ['nipplejs.min.js'])
+add_dependencies(__file__, ['nipplejs.min.js'])
 
 
 class JoystickView(CustomView):
@@ -18,6 +19,7 @@ class JoystickView(CustomView):
         self.on_start = on_start
         self.on_move = on_move
         self.on_end = on_end
+        self.style = 'position:relative;'
         self.allowed_events = ['onStart', 'onMove', 'onEnd']
         self.initialize(temp=False,
                         onStart=self.handle_start,
