@@ -12,12 +12,14 @@ class Menu(Group):
 
         :param value: whether the menu is already opened (default: `False`)
         """
-        view = jp.QMenu(value=value, temp=False)
+        view = jp.QMenu(value=value, temp=False, no_parent_event=True)
 
         super().__init__(view)
 
     def open(self):
         self.view.value = True
+        self.update()
 
     def close(self):
         self.view.value = False
+        self.update()
