@@ -5,15 +5,16 @@ from typing import Callable, Optional
 import websockets
 from justpy import WebPage
 
+from .. import globals
 from ..events import handle_event
-from ..globals import view_stack
+from ..page import Page
+from ..routes import add_dependencies
 from ..task_logger import create_task
 from .custom_view import CustomView
 from .element import Element
-from .page import Page
 from .scene_object3d import Object3D
 
-CustomView.use(__file__, [
+add_dependencies(__file__, [
     'three.min.js',
     'CSS2DRenderer.js',
     'CSS3DRenderer.js',
@@ -75,6 +76,9 @@ class SceneView(CustomView):
             pass
         return True
 
+    def __len__(self):
+        return len(self.objects)
+
 
 class Scene(Element):
     from .scene_objects import Box as box
@@ -107,14 +111,14 @@ class Scene(Element):
         super().__init__(SceneView(width=width, height=height, on_click=on_click))
 
     def __enter__(self):
-        view_stack.append(self.view)
+        globals.get_view_stack().append(self.view)
         scene = self.view.objects.get('scene', SceneObject(self.view, self.page))
         Object3D.stack.clear()
         Object3D.stack.append(scene)
         return self
 
     def __exit__(self, *_):
-        view_stack.pop()
+        globals.get_view_stack().pop()
 
     def move_camera(self,
                     x: Optional[float] = None,
