@@ -4,9 +4,10 @@ import traceback
 from collections import namedtuple
 from typing import Callable, List
 
+from . import globals
 from .binding import BindableProperty
-from .globals import tasks, view_stack
 from .helpers import is_coroutine
+from .page import find_parent_view
 from .task_logger import create_task
 
 NamedCoroutine = namedtuple('NamedCoroutine', ['name', 'coro'])
@@ -32,13 +33,14 @@ class Timer:
 
         self.active = active
         self.interval = interval
+        self.parent_view = find_parent_view()
 
         async def do_callback():
             try:
-                if is_coroutine(callback):
-                    return await callback()
-                else:
-                    return callback()
+                with globals.within_view(self.parent_view):
+                    result = callback()
+                    if is_coroutine(callback):
+                        await result
             except Exception:
                 traceback.print_exc()
 
@@ -61,8 +63,7 @@ class Timer:
                     await asyncio.sleep(self.interval)
 
         coroutine = timeout() if once else loop()
-        event_loop = asyncio.get_event_loop()
-        if not event_loop.is_running():
+        if not (globals.loop and globals.loop.is_running()):
             self.prepared_coroutines.append(NamedCoroutine(str(callback), coroutine))
         else:
-            tasks.append(create_task(coroutine, name=str(callback)))
+            globals.tasks.append(create_task(coroutine, name=str(callback)))
